@@ -1,11 +1,11 @@
 use crate::model::{BytesValue, U64Value};
 
-use super::Instance;
+use super::EsdtInstance;
 
 #[derive(Debug, Default)]
 pub struct EsdtObject {
     pub token_identifier: Option<BytesValue>,
-    pub instances: Vec<Instance>,
+    pub instances: Vec<EsdtInstance>,
     pub last_nonce: Option<U64Value>,
     pub roles: Vec<BytesValue>,
     pub frozen: Option<U64Value>,
