@@ -1,13 +1,19 @@
 mod address;
 mod address_value;
-mod value_basic;
 mod value_check;
+mod value_checkable;
 mod value_key_bytes;
 mod value_key_u64;
+mod value_set_big_uint;
+mod value_set_bytes;
+mod value_set_u64;
 
 pub use address::*;
 pub use address_value::*;
-pub use value_basic::*;
 pub use value_check::*;
+pub use value_checkable::*;
 pub use value_key_bytes::*;
 pub use value_key_u64::*;
+pub use value_set_big_uint::*;
+pub use value_set_bytes::*;
+pub use value_set_u64::*;
