@@ -26,8 +26,8 @@ pub struct InstanceRaw {
     pub hash: Option<ValueSubTree>,
 
     #[serde(default)]
-    #[serde(skip_serializing_if = "Option::is_none")]
-    pub uri: Option<ValueSubTree>,
+    #[serde(skip_serializing_if = "Vec::is_empty")]
+    pub uri: Vec<ValueSubTree>,
 
     #[serde(default)]
     #[serde(skip_serializing_if = "Option::is_none")]
