@@ -1,8 +1,8 @@
 extern crate mandos;
-use mandos::*;
 
 use std::{fs, fs::File, io::Write};
 
+use mandos::serde_raw::{ScenarioRaw, StepRaw};
 use serde::Serialize;
 
 #[test]
@@ -32,6 +32,7 @@ fn test_ser() {
         check_gas: Some(false),
         gas_schedule: Some("dummy".to_string()),
         steps: vec![StepRaw::ExternalSteps {
+            comment: None,
             path: "hello.txt".to_string(),
         }],
     };
